@@ -6,15 +6,17 @@
 #include <R_ext/Rdynload.h>
 
 #define CDEF(name)  {#name, (DL_FUNC) &name, sizeof(name ## _t)/sizeof(name ## _t[0]), name ##_t}
+#define CALLDEF(name, n)  {#name, (DL_FUNC) &name, n}
 
 
 static R_NativePrimitiveArgType R_bncoef_t[3] = {
     INTSXP, REALSXP, REALSXP
 };
 
-static R_NativePrimitiveArgType cl_clara_t[33] = {
+static R_NativePrimitiveArgType cl_clara_t[34] = {
     /*n:*/ INTSXP, INTSXP, INTSXP, REALSXP, INTSXP, INTSXP, REALSXP, INTSXP,
     /*valmd:*/ REALSXP, INTSXP, INTSXP, /* rng_R: */ LGLSXP, /* pam_like:*/ LGLSXP,
+    /*d_flag:*/ INTSXP,
     /*nrepr: */ INTSXP, INTSXP, INTSXP, INTSXP, INTSXP,
     /*radus:*/ REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, REALSXP, INTSXP,
     /*obj: */ REALSXP, REALSXP, REALSXP, REALSXP,  INTSXP, INTSXP,
@@ -33,7 +35,7 @@ static R_NativePrimitiveArgType cl_pam_t[24] = {
     INTSXP, INTSXP, INTSXP, REALSXP, REALSXP,
     /*jdyss: */ INTSXP, REALSXP, INTSXP,  INTSXP, INTSXP,
     /*nrepr: */ LGLSXP, INTSXP, /*radus: */ REALSXP, REALSXP, REALSXP, REALSXP,
-    /*ttsyl: */ REALSXP, REALSXP, INTSXP, INTSXP,  REALSXP, REALSXP, INTSXP,
+    /*ttsyl: */ REALSXP, REALSXP, /*medoids*/ INTSXP, INTSXP,  REALSXP, REALSXP, INTSXP,
     /*optim: */ INTSXP
 };
 
@@ -73,10 +75,10 @@ static const R_CMethodDef CEntries[]  = {
     {NULL, NULL, 0}
 };
 
-/* static R_CallMethodDef CallEntries[] = {
- *     {NULL, NULL, 0}
- * };
- */
+static R_CallMethodDef CallEntries[] = {
+    CALLDEF(cl_Pam, 13),
+    {NULL, NULL, 0}
+};
 
 static R_FortranMethodDef FortEntries[] = {
     {"cl_daisy", (DL_FUNC) &F77_SUB(cldaisy), 11},
@@ -87,6 +89,6 @@ static R_FortranMethodDef FortEntries[] = {
 
 void R_init_cluster(DllInfo *dll)
 {
-    R_registerRoutines(dll, CEntries, NULL/*CallEntries*/, FortEntries, NULL);
+    R_registerRoutines(dll, CEntries, CallEntries, FortEntries, NULL);
     R_useDynamicSymbols(dll, FALSE);
 }
